@@ -1,9 +1,7 @@
 from nose.tools import assert_equals, assert_raises
 from nose.plugins.skip import SkipTest
 
-import requests
-
-from blackbelt.config import config
+import os
 
 from blackbelt.hipchat import Client
 
@@ -21,5 +19,8 @@ class TestBuildInfoRetrieval(object):
         except ValueError:
             raise SkipTest()
 
-    # def test_posting_message(self):
-    #     self.client.post_message("Testing HipChat Messages in Black Belt Exploratory Test Suite")
+        if os.environ.get('FORCE_DISCOVERY') != '1':
+            raise SkipTest()
+
+    def test_posting_message(self):
+        self.client.post_message("Testing HipChat Messages in Black Belt Exploratory Test Suite")
